@@ -67,6 +67,7 @@ __all__ = (
     "DeleteBackupSelectionInputRequestTypeDef",
     "DeleteBackupVaultAccessPolicyInputRequestTypeDef",
     "DeleteBackupVaultInputRequestTypeDef",
+    "DeleteBackupVaultLockConfigurationInputRequestTypeDef",
     "DeleteBackupVaultNotificationsInputRequestTypeDef",
     "DeleteFrameworkInputRequestTypeDef",
     "DeleteRecoveryPointInputRequestTypeDef",
@@ -144,6 +145,7 @@ __all__ = (
     "ListTagsOutputTypeDef",
     "ProtectedResourceTypeDef",
     "PutBackupVaultAccessPolicyInputRequestTypeDef",
+    "PutBackupVaultLockConfigurationInputRequestTypeDef",
     "PutBackupVaultNotificationsInputRequestTypeDef",
     "RecoveryPointByBackupVaultTypeDef",
     "RecoveryPointByResourceTypeDef",
@@ -375,6 +377,10 @@ BackupVaultListMemberTypeDef = TypedDict(
         "EncryptionKeyArn": str,
         "CreatorRequestId": str,
         "NumberOfRecoveryPoints": int,
+        "Locked": bool,
+        "MinRetentionDays": int,
+        "MaxRetentionDays": int,
+        "LockDate": datetime,
     },
     total=False,
 )
@@ -620,6 +626,7 @@ CreateReportPlanOutputTypeDef = TypedDict(
     {
         "ReportPlanName": str,
         "ReportPlanArn": str,
+        "CreationTime": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -664,6 +671,13 @@ DeleteBackupVaultInputRequestTypeDef = TypedDict(
     },
 )
 
+DeleteBackupVaultLockConfigurationInputRequestTypeDef = TypedDict(
+    "DeleteBackupVaultLockConfigurationInputRequestTypeDef",
+    {
+        "BackupVaultName": str,
+    },
+)
+
 DeleteBackupVaultNotificationsInputRequestTypeDef = TypedDict(
     "DeleteBackupVaultNotificationsInputRequestTypeDef",
     {
@@ -743,6 +757,10 @@ DescribeBackupVaultOutputTypeDef = TypedDict(
         "CreationDate": datetime,
         "CreatorRequestId": str,
         "NumberOfRecoveryPoints": int,
+        "Locked": bool,
+        "MinRetentionDays": int,
+        "MaxRetentionDays": int,
+        "LockDate": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1521,6 +1539,30 @@ class PutBackupVaultAccessPolicyInputRequestTypeDef(
     pass
 
 
+_RequiredPutBackupVaultLockConfigurationInputRequestTypeDef = TypedDict(
+    "_RequiredPutBackupVaultLockConfigurationInputRequestTypeDef",
+    {
+        "BackupVaultName": str,
+    },
+)
+_OptionalPutBackupVaultLockConfigurationInputRequestTypeDef = TypedDict(
+    "_OptionalPutBackupVaultLockConfigurationInputRequestTypeDef",
+    {
+        "MinRetentionDays": int,
+        "MaxRetentionDays": int,
+        "ChangeableForDays": int,
+    },
+    total=False,
+)
+
+
+class PutBackupVaultLockConfigurationInputRequestTypeDef(
+    _RequiredPutBackupVaultLockConfigurationInputRequestTypeDef,
+    _OptionalPutBackupVaultLockConfigurationInputRequestTypeDef,
+):
+    pass
+
+
 PutBackupVaultNotificationsInputRequestTypeDef = TypedDict(
     "PutBackupVaultNotificationsInputRequestTypeDef",
     {
@@ -1642,12 +1684,25 @@ ReportPlanTypeDef = TypedDict(
     total=False,
 )
 
-ReportSettingTypeDef = TypedDict(
-    "ReportSettingTypeDef",
+_RequiredReportSettingTypeDef = TypedDict(
+    "_RequiredReportSettingTypeDef",
     {
         "ReportTemplate": str,
     },
 )
+_OptionalReportSettingTypeDef = TypedDict(
+    "_OptionalReportSettingTypeDef",
+    {
+        "FrameworkArns": Sequence[str],
+        "NumberOfFrameworks": int,
+    },
+    total=False,
+)
+
+
+class ReportSettingTypeDef(_RequiredReportSettingTypeDef, _OptionalReportSettingTypeDef):
+    pass
+
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
